package com.zehong.system.service;

import java.util.List;
import com.zehong.system.domain.TCarTask;

/**
 * 巡检车任务Service接口
 * 
 * @author zehong
 * @date 2026-05-15
 */
public interface ITCarTaskService 
{
    /**
     * 查询巡检车任务
     * 
     * @param id 巡检车任务ID
     * @return 巡检车任务
     */
    public TCarTask selectTCarTaskById(Long id);

    /**
     * 查询巡检车任务列表
     * 
     * @param tCarTask 巡检车任务
     * @return 巡检车任务集合
     */
    public List<TCarTask> selectTCarTaskList(TCarTask tCarTask);

    /**
     * 新增巡检车任务
     * 
     * @param tCarTask 巡检车任务
     * @return 结果
     */
    public int insertTCarTask(TCarTask tCarTask);

    /**
     * 修改巡检车任务
     * 
     * @param tCarTask 巡检车任务
     * @return 结果
     */
    public int updateTCarTask(TCarTask tCarTask);

    /**
     * 批量删除巡检车任务
     * 
     * @param ids 需要删除的巡检车任务ID
     * @return 结果
     */
    public int deleteTCarTaskByIds(Long[] ids);

    /**
     * 删除巡检车任务信息
     * 
     * @param id 巡检车任务ID
     * @return 结果
     */
    public int deleteTCarTaskById(Long id);
}
